@@ -2,6 +2,7 @@ import os
 import json
 from django.conf import settings
 from django.http import JsonResponse
+# from clixdev.apps.clix import validators
 
 
 class Middleware:
@@ -42,6 +43,20 @@ class Middleware:
 
         # request = detecting correct endpoint details based on Request URI (if not in list pass)
 
+        """
+    Sudo code:
+        if uri:
+            if method:
+                check headers (1.exist 2.type check)
+                check params (1.exist 2.type check)
+                check body*
+                check response*
+            else:
+                error method not allowed
+        else:
+            let django handle (endpoint doesn't exist)
+        """
+
         # validating request method
         # if str(request.method) != str(app['endpoints'][0]['request']['method']):
         #     has_errors = True
