@@ -125,14 +125,14 @@ def SETTINGS(settings):
     return f"""from clixdev.apps.clix.settings import *
 
 DEBUG = True
+
 ALLOWED_HOSTS += []
+INSTALLED_APPS += []
+MIDDLEWARE += []
 
 #### SETTINGS ####
 {''.join([setting for setting in settings])}
 
-
-INSTALLED_APPS += []
-MIDDLEWARE += []
 """
 
 
@@ -149,7 +149,7 @@ application = get_wsgi_application()
 
 def VIEWS(app):
     endpoints = app['endpoints']
-    defs = ["from django.http import JsonResponse\nfrom clixdev.apps.clix.models import *\nfrom django.views.decorators.csrf import csrf_exempt"]
+    defs = ["import json\nfrom django.http import JsonResponse\nfrom clixdev.apps.clix.models import *\nfrom django.views.decorators.csrf import csrf_exempt"]
 
     for endpoint in endpoints:
         misc = endpoint['misc']
@@ -170,6 +170,7 @@ def VIEWS(app):
 {header_code}{params_code}{body_code}
 
 \treturn JsonResponse({{{responses}}})
+
 """)
 # removed for beta
 # \t#### Add Your Logic Here ####
